@@ -5,12 +5,13 @@ use 5.006002;
 use strict;
 use warnings;
 
-use base qw{ Exporter };
+use Exporter ();
+our @ISA = qw{ Exporter };
 
 use Carp;
 use Test::More 0.88;
 
-our $VERSION = '0.007_08';
+our $VERSION = '0.008_01';
 
 our %EXPORT_TAGS = (
     const	=> [ qw{ IS_WINDOWS } ],
@@ -169,7 +170,7 @@ Tom Wyant (wyant at cpan dot org)
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2016 by Thomas R. Wyant, III
+Copyright (C) 2016-2017, 2019 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
