@@ -8,7 +8,7 @@ use warnings;
 use Carp;
 use Time::Local ();
 
-our $VERSION = '0.007_08';
+our $VERSION = '0.008_01';
 
 my %mock = (
     KERNEL32	=> {
@@ -91,7 +91,7 @@ foreach my $dll ( keys %mock ) {
 
 sub new {
     my ( $class, $lib, $sub, $arg, $ret ) = @_;
-    my $mock = join '__', '_mock', $lib, $sub;
+#   my $mock = join '__', '_mock', $lib, $sub;
     $mock{$lib}
 	or croak "No mock code available for $lib.dll";
     my $info = $mock{$lib}{$sub}
@@ -136,7 +136,7 @@ sub Call {
 }
 
 {
-    my $size_quad = _size( pack 'LL', 0, 0 );
+#   my $size_quad = _size( pack 'LL', 0, 0 );
 
     my %valid = (
 	N	=> sub {
@@ -248,7 +248,7 @@ Tom Wyant (wyant at cpan dot org)
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2016 by Thomas R. Wyant, III
+Copyright (C) 2016-2017, 2019 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
